/**
 * Copyright (C) 2011 Gauvain Pocentek <gpocentek@linutop.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "text-utils.h"

static gchar *img (const gchar *path);

static struct action {
    const gchar *pattern;
    gchar * (*replacement_func) (const gchar *path);
} actions[] = {
    { "<limage([^>]*)>(.*/)?([^/]+)</limage>", img },
    { NULL, NULL }
};

static gchar *
text_modify (const gchar *src, const gchar *data_path)
{
    struct action *ap;
    GRegex *re;
    gchar *tmp, *new;
    gchar *replacement;

    new = g_strdup (src);

    for (ap = actions; ap->pattern; ap++)
    {
        replacement = ap->replacement_func (data_path);
        tmp = new;
        re = g_regex_new (ap->pattern, G_REGEX_UNGREEDY | G_REGEX_CASELESS, 0, NULL);
        new = g_regex_replace (re, tmp, -1, 0, replacement, 0, NULL);
        g_regex_unref (re);
        g_free (tmp);
        g_free (replacement);
    }

    return new;
}

static gchar *
img (const gchar *path)
{
    return g_strdup_printf ("<img src=\"%s\\3\" \\1 />", path);
}

void
text_fill_cache (const gchar *src_file, const gchar *data_path)
{
    gchar *orig_content;
    gchar *new_content;

    if (! g_file_get_contents (src_file, &orig_content, NULL, NULL))
        return;

    new_content = text_modify (orig_content, data_path);

    g_file_set_contents (src_file, new_content, -1, NULL);
}

