/**
 * Copyright (C) 2007-2011 Linutop SAS <http://www.linutop.com/>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "wk-logger.h"

#define IDENT "linutop-webkiosk"

struct _WkLoggerPrivate
{
};

static void wk_logger_class_init (WkLoggerClass *klass);
static void wk_logger_init       (WkLogger *logger);
static void wk_logger_finalize   (GObject *object);

G_DEFINE_TYPE (WkLogger, wk_logger, G_TYPE_OBJECT);

static void
wk_logger_class_init (WkLoggerClass *klass)
{
    /* g_type_class_add_private (klass, sizeof (WkLoggerPrivate)); */

    GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
    gobject_class->finalize = wk_logger_finalize;
}

static void
wk_logger_init (WkLogger *logger)
{
    /* logger->priv = G_TYPE_INSTANCE_GET_PRIVATE (logger,
                                                WK_TYPE_LOGGER,
                                                WkLoggerPrivate); */

    openlog (IDENT, 0, LOG_LOCAL0);
}

static void
wk_logger_finalize (GObject *object)
{
    closelog ();

    (*G_OBJECT_CLASS (wk_logger_parent_class)->finalize) (object);
}

/* Public API */
GObject *
wk_logger_get ()
{
    static WkLogger *logger = NULL;

    if (G_LIKELY (logger != NULL))
    {
        g_object_ref (G_OBJECT (logger));
        return G_OBJECT (logger);
    }

    logger = g_object_new (WK_TYPE_LOGGER, NULL);
    g_object_add_weak_pointer (G_OBJECT (logger), (gpointer) &logger);

    return G_OBJECT (logger);
}

gboolean
wk_logger_write (WkLogger *logger, int priority,
                 const gchar *format, ...)
{
    va_list parameters;

    va_start (parameters, format);
    vsyslog (priority, format, parameters);
    va_end (parameters);

    return TRUE;
}

