/**
 * Copyright (C) 2012 Gauvain Pocentek <gpocentek@linutop.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "wk-config-item.h"

WkConfigItem *
wk_config_item_new (const gchar   *section,
                    const gchar   *key,
                    const gchar   *uri,
                    WkConfigItemType type,
                    gpointer       value)
{
    g_return_val_if_fail (section != NULL, NULL);
    g_return_val_if_fail (key != NULL, NULL);

    WkConfigItem *item;

    item = g_new (WkConfigItem, 1);

    item->section = g_strdup (section);
    item->key = g_strdup (key);
    item->uri = uri ? g_strdup (uri) : NULL;
    item->type = type;
    item->value = value;

    return item;
}

WkConfigItemType
wk_config_item_get_type (WkConfigItem *item)
{
    g_return_val_if_fail (item != NULL, WK_CONFIG_ITEM_TYPE_INVALID);

    return item->type;
}

void
wk_config_item_set_value (WkConfigItem *item,
                          gpointer    value,
                          gboolean    free_old)
{
    g_return_if_fail (item != NULL);

    switch (item->type)
    {
    case WK_CONFIG_ITEM_TYPE_STRING:
        if (free_old)
            g_free ((gchar *) item->value);
        item->value = value;
        break;

    case WK_CONFIG_ITEM_TYPE_INT:
    case WK_CONFIG_ITEM_TYPE_BOOLEAN:
        item->value = value;
        break;

    default:
        break;
    }
}

gpointer
wk_config_item_get_value (WkConfigItem *item)
{
    return item->value;
}

void
wk_config_item_get (WkConfigItem *item, const gchar **section,
                    const gchar **key, const gchar **uri,
                    guint *type, gpointer *value)
{
    g_return_if_fail (item != NULL);

    *section = item->section;
    *key = item->section;
    *type = item->type;
    *value = item->value;
}

void
wk_config_item_free (WkConfigItem *item)
{
    g_free ((gchar *)item->section);
    g_free ((gchar *)item->key);
    g_free ((gchar *)item->uri);

    switch (item->type)
    {
    case WK_CONFIG_ITEM_TYPE_STRING:
        g_free ((gchar *) item->value);
        break;

    default:
        break;
    }

    g_free (item);
}
