/**
 * Copyright (C) 2012 Linutop SAS <http://www.linutop.com/>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef HAVE_STRING_H
#include <string.h>
#endif

#ifdef HAVE_STDLIB_H
#include <stdlib.h>
#endif

#include "settings.h"
#include "gtk-extensions.h"
#include "xfce_framebox.h"

#include "main.h"
#include "utils.h"

static GtkWidget *proxy_use_checkbox;
static GtkWidget *uri_entry, *user_entry, *passwd_entry;

WkConfigItemDesc network_descs[] =
{
    { "network", "proxy_use", WK_CONFIG_ITEM_TYPE_BOOLEAN, "false" },
    { "network", "proxy_uri", WK_CONFIG_ITEM_TYPE_STRING, "" },
    { "network", "proxy_user", WK_CONFIG_ITEM_TYPE_STRING, "" },
    { "network", "proxy_passwd", WK_CONFIG_ITEM_TYPE_STRING, "" },
    { NULL }
};

inline GHashTable *
config_network_get_hash (WkKeyFile *kf)
{
    return handled_settings_get_from_array (kf, network_descs);
}

static void
on_proxy_use_toggled (GtkToggleButton *b, gpointer data)
{
    gboolean active = gtk_toggle_button_get_active (b);

    gtk_widget_set_sensitive (uri_entry, active);
    gtk_widget_set_sensitive (user_entry, active);
    gtk_widget_set_sensitive (passwd_entry, active);
}

GtkWidget *
config_network_get_widget (GHashTable *hash)
{
    GtkWidget *mvbox;
    GtkWidget *vbox, *hbox, *ibox;
    GtkWidget *frame;
    GtkWidget *label;
    GtkSizeGroup *sg;

    mvbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 2);

    hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
    gtk_box_pack_start (GTK_BOX (mvbox), hbox, FALSE, FALSE, 0);

    vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 2);

    frame = xfce_framebox_new (_("Proxy"), TRUE);
    xfce_framebox_add (XFCE_FRAMEBOX (frame), vbox);
    gtk_box_pack_start (GTK_BOX (hbox), frame, FALSE, FALSE, 6);

    proxy_use_checkbox = wk_gtk_check_button_new (_("Use a proxy"),
                            g_hash_table_lookup (hash, "network:proxy_use"),
                            FALSE),

    g_signal_connect (G_OBJECT (proxy_use_checkbox), "toggled",
                      G_CALLBACK (on_proxy_use_toggled), NULL);

    gtk_box_pack_start (GTK_BOX (vbox), proxy_use_checkbox, FALSE, FALSE, 2);

    sg = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);

    ibox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 2);
    label = gtk_label_new (_("Proxy URI: "));
    gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
    gtk_size_group_add_widget (sg, label);
    uri_entry = wk_gtk_entry_new (g_hash_table_lookup (hash, "network:proxy_uri"));
    gtk_box_pack_start (GTK_BOX (ibox), label, FALSE, FALSE, 2);
    gtk_box_pack_start (GTK_BOX (ibox), uri_entry, FALSE, FALSE, 2);
    gtk_box_pack_start (GTK_BOX (vbox), ibox, FALSE, FALSE, 2);

    ibox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 2);
    label = gtk_label_new (_("Proxy User: "));
    gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
    gtk_size_group_add_widget (sg, label);
    user_entry = wk_gtk_entry_new (g_hash_table_lookup (hash, "network:proxy_user"));
    gtk_box_pack_start (GTK_BOX (ibox), label, FALSE, FALSE, 2);
    gtk_box_pack_start (GTK_BOX (ibox), user_entry, FALSE, FALSE, 2);
    gtk_box_pack_start (GTK_BOX (vbox), ibox, FALSE, FALSE, 2);

    ibox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 2);
    label = gtk_label_new (_("Proxy Password: "));
    gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
    gtk_size_group_add_widget (sg, label);
    passwd_entry = wk_gtk_entry_new (g_hash_table_lookup (hash, "network:proxy_passwd"));
    gtk_box_pack_start (GTK_BOX (ibox), label, FALSE, FALSE, 2);
    gtk_box_pack_start (GTK_BOX (ibox), passwd_entry, FALSE, FALSE, 2);
    gtk_box_pack_start (GTK_BOX (vbox), ibox, FALSE, FALSE, 2);
    gtk_entry_set_visibility (GTK_ENTRY (passwd_entry), FALSE);

    on_proxy_use_toggled (GTK_TOGGLE_BUTTON (proxy_use_checkbox), NULL);

    gtk_widget_show_all (mvbox);

    return mvbox;
}

void
config_network_save_config (WkKeyFile *kf, GHashTable *hash)
{
    handled_settings_set_from_hash (kf, hash);
}

